# Notebooks accompanying the satsense Python package

## FeatureExtraction
Notebooks demonstrating how to extract features from satellite images using
satsense.

## Performance
Notebooks demonstrating how to use the performance metrics with satsense and
the utility functions to convert ground truth data to and from mask files and
shapefiles.

## Classification

Notebooks demonstrating classification using features calculated with Satsense.
